@@ -15,10 +15,9 @@
 
 
 """
-Python library for generating and representing CycloneDX software bill-of-materials.
+Python library for CycloneDX
 """
 
 # !! version is managed by semantic_release
 # do not use typing here, or else `semantic_release` might have issues finding the variable
-# flake8: noqa
-__version__ = "6.2.0"
+__version__ = "6.4.2"  # noqa:Q000
